@@ -1,43 +1,47 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
+# ---------------------------------------------------------------------------##
+#
+# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 2003 Mt. Hood Playing Card Co.
+# Copyright (C) 2005-2009 Skomoroh
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------##
 
-__all__ = []
-
-# imports
-import sys
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import *
-from pysollib.stack import *
 from pysollib.game import Game
+from pysollib.gamedb import GI, GameInfo, registerGame
+from pysollib.hint import DefaultHint
 from pysollib.layout import Layout
-from pysollib.hint import AbstractHint, DefaultHint, CautiousDefaultHint
+from pysollib.stack import \
+        AbstractFoundationStack, \
+        BasicRowStack, \
+        DealRowRedealTalonStack, \
+        InitialDealTalonStack, \
+        OpenStack, \
+        ReserveStack, \
+        SS_FoundationStack, \
+        StackWrapper, \
+        TalonStack
+from pysollib.util import ANY_RANK, ANY_SUIT, KING, NO_RANK, UNLIMITED_REDEALS
 
 # ************************************************************************
 # *
 # ************************************************************************
 
+
 class MonteCarlo_Hint(DefaultHint):
     # FIXME: demo is not too clever in this game
     pass
@@ -59,9 +63,9 @@ class MonteCarlo_Talon(TalonStack):
         return free and len(self.cards)
 
     def dealCards(self, sound=False):
-        self.game.updateStackMove(self.game.s.talon, 2|16)  # for undo
+        self.game.updateStackMove(self.game.s.talon, 2 | 16)  # for undo
         n = self.game.fillEmptyStacks()
-        self.game.updateStackMove(self.game.s.talon, 1|16)  # for redo
+        self.game.updateStackMove(self.game.s.talon, 1 | 16)  # for redo
         return n
 
 
@@ -80,13 +84,14 @@ class MonteCarlo_RowStack(BasicRowStack):
         if to_stack.cards:
             self._dropPairMove(ncards, to_stack, frames=-1, shadow=shadow)
         else:
-            BasicRowStack.moveMove(self, ncards, to_stack, frames=frames, shadow=shadow)
+            BasicRowStack.moveMove(
+                self, ncards, to_stack, frames=frames, shadow=shadow)
 
     def _dropPairMove(self, n, other_stack, frames=-1, shadow=-1):
         game = self.game
         old_state = game.enterState(game.S_FILL)
         f = game.s.foundations[0]
-        game.updateStackMove(game.s.talon, 2|16)            # for undo
+        game.updateStackMove(game.s.talon, 2 | 16)            # for undo
         if not game.demo:
             game.playSample("droppair", priority=200)
         game.moveMove(n, self, f, frames=frames, shadow=shadow)
@@ -95,13 +100,14 @@ class MonteCarlo_RowStack(BasicRowStack):
         other_stack.fillStack()
         if self.game.FILL_STACKS_AFTER_DROP:
             game.fillEmptyStacks()
-        game.updateStackMove(game.s.talon, 1|16)            # for redo
+        game.updateStackMove(game.s.talon, 1 | 16)            # for redo
         game.leaveState(old_state)
 
 
 class MonteCarlo(Game):
     Talon_Class = MonteCarlo_Talon
-    Foundation_Class = StackWrapper(AbstractFoundationStack, max_accept=0)
+    Foundation_Class = StackWrapper(
+        AbstractFoundationStack, max_accept=0)
     RowStack_Class = MonteCarlo_RowStack
     Hint_Class = MonteCarlo_Hint
 
@@ -142,8 +148,7 @@ class MonteCarlo(Game):
     #
 
     def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
     def getAutoStacks(self, event=None):
         return ((), (), self.sg.dropstacks)
@@ -151,7 +156,6 @@ class MonteCarlo(Game):
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
         return card1.rank == card2.rank
 
-
     #
     # game extras
     #
@@ -272,11 +276,11 @@ class SimplePairs(MonteCarlo):
         # create stacks
         for i in range(3):
             for j in range(3):
-                x, y = l.XM + (2*j+3)*l.XS/2, l.YM + (2*i+1)*l.YS/2
+                x, y = l.XM + (2*j+3)*l.XS//2, l.YM + (2*i+1)*l.YS//2
                 s.rows.append(self.RowStack_Class(x, y, self,
                                                   max_accept=1, max_cards=2,
                                                   dir=0, base_rank=NO_RANK))
-        x, y = l.XM, l.YM + 3*l.YS/2
+        x, y = l.XM, l.YM + 3*l.YS//2
         s.talon = TalonStack(x, y, self, max_rounds=1)
         l.createText(s.talon, "s")
         x = x + 5*l.XS
@@ -328,9 +332,11 @@ class Neighbour_RowStack(MonteCarlo_RowStack):
         assert ncards == 1
         if self.cards[-1].rank == KING:
             assert to_stack in self.game.s.foundations
-            BasicRowStack.moveMove(self, ncards, to_stack, frames=frames, shadow=shadow)
+            BasicRowStack.moveMove(
+                self, ncards, to_stack, frames=frames, shadow=shadow)
         else:
-            MonteCarlo_RowStack.moveMove(self, ncards, to_stack, frames=frames, shadow=shadow)
+            MonteCarlo_RowStack.moveMove(
+                self, ncards, to_stack, frames=frames, shadow=shadow)
 
     def _dropKingClickHandler(self, event):
         if not self.cards:
@@ -400,7 +406,7 @@ class Fourteen(Game):
                                                   dir=0, base_rank=NO_RANK))
         x, y = l.XM + 6*l.XS, l.YM
         s.foundations.append(self.Foundation_Class(x, y, self, suit=ANY_SUIT,
-                                max_move=0, max_cards=52, base_rank=ANY_RANK))
+                             max_move=0, max_cards=52, base_rank=ANY_RANK))
         l.createText(s.foundations[0], "s")
         x, y = self.width - l.XS, self.height - l.YS
         s.talon = InitialDealTalonStack(x, y, self)
@@ -413,9 +419,7 @@ class Fourteen(Game):
     #
 
     def startGame(self):
-        for i in range(3):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
+        self._startDealNumRows(3)
         self.s.talon.dealRow()
         self.s.talon.dealRow(rows=self.s.rows[:4])
 
@@ -470,7 +474,7 @@ class Nestor(Game):
             x += l.XS
         x, y = self.width-l.XS, self.height-l.YS
         s.foundations.append(self.Foundation_Class(x, y, self, suit=ANY_SUIT,
-                                max_move=0, max_cards=52, base_rank=ANY_RANK))
+                             max_move=0, max_cards=52, base_rank=ANY_RANK))
         l.createText(s.foundations[0], "n")
         x, y = l.XM, self.height - l.YS
         s.talon = InitialDealTalonStack(x, y, self)
@@ -492,12 +496,12 @@ class Nestor(Game):
     def _shuffleHook(self, cards):
         # no row will have two cards of the same rank
         for i in range(8):
-            for t in range(1000): # just in case
+            for t in range(1000):  # just in case
                 j = self._checkRow(cards[i*6:(i+1)*6])
                 if j < 0:
                     break
                 j += i*6
-                k = self.random.choice(range((i+1)*6, 52))
+                k = self.random.choice(list(range((i+1)*6, 52)))
                 cards[j], cards[k] = cards[k], cards[j]
         cards.reverse()
         return cards
@@ -552,7 +556,6 @@ class Vertical(Nestor):
         # define stack-groups
         l.defaultStackGroups()
 
-
     def startGame(self):
         self.s.talon.dealRow(frames=0)
         for i in range(4):
@@ -562,7 +565,6 @@ class Vertical(Nestor):
         self.s.talon.dealRow(rows=[self.s.rows[3]])
 
 
-
 # ************************************************************************
 # * The Wish
 # ************************************************************************
@@ -590,8 +592,10 @@ class TheWish(Game):
         s.talon = InitialDealTalonStack(x, y, self)
 
         x, y = self.width - l.XS, self.height - l.YS
-        s.foundations.append(AbstractFoundationStack(x, y, self, suit=ANY_SUIT,
-                             max_move=0, max_cards=32, max_accept=0, base_rank=ANY_RANK))
+        s.foundations.append(
+            AbstractFoundationStack(
+                x, y, self, suit=ANY_SUIT,
+                max_move=0, max_cards=32, max_accept=0, base_rank=ANY_RANK))
         l.createText(s.foundations[0], "n")
 
         # define stack-groups
@@ -604,8 +608,7 @@ class TheWish(Game):
     def startGame(self):
         for i in range(3):
             self.s.talon.dealRow(flip=0, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
     def fillStack(self, stack):
         if stack.cards:
@@ -617,24 +620,25 @@ class TheWish(Game):
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
         return card1.rank == card2.rank
 
+
 class TheWishOpen(TheWish):
     def fillStack(self, stack):
         pass
+
     def startGame(self):
-        for i in range(3):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startDealNumRowsAndDealSingleRow(3)
 
 # ************************************************************************
 # * Der letzte Monarch (The last Monarch)
 # ************************************************************************
 
+
 class DerLetzteMonarch_Foundation(SS_FoundationStack):
     def acceptsCards(self, from_stack, cards):
         if cards is None:
             # special hack for _getDropStack() below
-            return SS_FoundationStack.acceptsCards(self, from_stack, from_stack.cards)
+            return SS_FoundationStack.acceptsCards(
+                self, from_stack, from_stack.cards)
         #
         if not SS_FoundationStack.acceptsCards(self, from_stack, cards):
             return False
@@ -714,14 +718,18 @@ class DerLetzteMonarch(Game):
         for i in range(4):
             for j in range(13):
                 x, y, = dx + l.XM + j*l.XS, l.YM + (i+1)*l.YS
-                s.rows.append(DerLetzteMonarch_RowStack(x, y, self, max_accept=1, max_cards=2))
+                s.rows.append(
+                    DerLetzteMonarch_RowStack(
+                        x, y, self, max_accept=1, max_cards=2))
         for i in range(4):
             x, y, = l.XM + (i+2)*l.XS, l.YM
-            s.reserves.append(DerLetzteMonarch_ReserveStack(x, y, self, max_accept=0))
+            s.reserves.append(
+                DerLetzteMonarch_ReserveStack(
+                    x, y, self, max_accept=0))
         for i in range(4*decks):
             x, y, = l.XM + (i+7)*l.XS, l.YM
             s.foundations.append(DerLetzteMonarch_Foundation(x, y, self,
-                                 suit=i%4, max_move=0))
+                                 suit=i % 4, max_move=0))
         s.talon = self.Talon_Class(l.XM, l.YM, self)
         if texts:
             l.createText(s.talon, 'ne')
@@ -753,7 +761,6 @@ class DerLetzteMonarch(Game):
     def getDemoInfoText(self):
         return "Der letzte\nMonarch"
 
-
     #
     # game extras
     #
@@ -791,7 +798,7 @@ class TheLastMonarchII(DerLetzteMonarch):
 # ************************************************************************
 
 class DoubletsII(Game):
-    FILL_STACKS_AFTER_DROP = False # for Nestor_RowStack
+    FILL_STACKS_AFTER_DROP = False  # for Nestor_RowStack
 
     def createGame(self):
         l, s = Layout(self), self.s
@@ -818,8 +825,7 @@ class DoubletsII(Game):
     def startGame(self):
         for i in range(3):
             self.s.talon.dealRow(frames=0, flip=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
     def fillStack(self, stack):
         if stack in self.s.rows:
@@ -878,15 +884,13 @@ class RightAndLeft(Game):
         l.defaultStackGroups()
 
     def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow()
-
+        self._startAndDealRow()
 
 
 # register the game
 registerGame(GameInfo(89, MonteCarlo, "Monte Carlo",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK,
-                      altnames=("Quilt",) ))
+                      altnames=("Quilt",)))
 registerGame(GameInfo(216, MonteCarlo2Decks, "Monte Carlo (2 decks)",
                       GI.GT_PAIRING_TYPE, 2, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(212, Weddings, "Weddings",
@@ -899,24 +903,28 @@ registerGame(GameInfo(91, SimplePairs, "Simple Pairs",
 registerGame(GameInfo(92, Neighbour, "Neighbour",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(96, Fourteen, "Fourteen",
-                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_LUCK))
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
+                      GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(235, Nestor, "Nestor",
-                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_LUCK))
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
+                      GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(152, DerLetzteMonarch, "The Last Monarch",
                       GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
-                      altnames=("Der letzte Monarch",) ))
+                      altnames=("Der letzte Monarch",)))
 registerGame(GameInfo(328, TheWish, "The Wish",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK,
-                      ranks=(0, 6, 7, 8, 9, 10, 11, 12) ))
+                      ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
 registerGame(GameInfo(329, TheWishOpen, "The Wish (open)",
-                      GI.GT_PAIRING_TYPE | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 0, GI.SL_MOSTLY_SKILL,
-                      ranks=(0, 6, 7, 8, 9, 10, 11, 12) ))
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 0,
+                      GI.SL_MOSTLY_SKILL,
+                      ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
 registerGame(GameInfo(368, Vertical, "Vertical",
-                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_LUCK))
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
+                      GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(649, DoubletsII, "Doublets II",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(663, TheLastMonarchII, "The Last Monarch II",
-                      GI.GT_2DECK_TYPE | GI.GT_ORIGINAL, 2, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_2DECK_TYPE | GI.GT_ORIGINAL, 2, 0,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(727, RightAndLeft, "Right and Left",
                       GI.GT_PAIRING_TYPE, 2, -1, GI.SL_LUCK))
-
