@@ -21,13 +21,14 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.mygettext import _
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import ANY_SUIT, KING
+from pysollib.game import Game
+from pysollib.gamedb import GI, GameInfo, registerGame
+from pysollib.games.spider import Spider_SS_Foundation
+from pysollib.hint import Yukon_Hint
+from pysollib.layout import Layout
 from pysollib.mfxutil import kwdefault
+from pysollib.mygettext import _
+from pysollib.pysoltk import MfxCanvasText
 from pysollib.stack import \
     DealRowTalonStack, \
     InitialDealTalonStack, \
@@ -36,17 +37,11 @@ from pysollib.stack import \
     ReserveStack, \
     SS_FoundationStack, \
     StackWrapper, \
-    Yukon_AC_RowStack, \
-    Yukon_SS_RowStack, \
     WasteStack, \
-    WasteTalonStack
-
-from pysollib.game import Game
-from pysollib.layout import Layout
-from pysollib.hint import Yukon_Hint
-from pysollib.pysoltk import MfxCanvasText
-
-from pysollib.games.spider import Spider_SS_Foundation
+    WasteTalonStack, \
+    Yukon_AC_RowStack, \
+    Yukon_SS_RowStack
+from pysollib.util import ANY_SUIT, KING
 
 
 # ************************************************************************
@@ -106,7 +101,7 @@ class RussianSolitaire(Yukon):
 # ************************************************************************
 
 class Moosehide_RowStack(Yukon_AC_RowStack):
-    def _isSequence(self, c1, c2):
+    def _isYukonSequence(self, c1, c2):
         return (c1.suit != c2.suit and c1.rank == c2.rank+1)
 
     def getHelp(self):
@@ -177,7 +172,7 @@ class Grandfather(RussianSolitaire):
 # ************************************************************************
 
 class Alaska_RowStack(Yukon_SS_RowStack):
-    def _isSequence(self, c1, c2):
+    def _isYukonSequence(self, c1, c2):
         return (c1.suit == c2.suit and
                 ((c1.rank + self.cap.dir) % self.cap.mod == c2.rank or
                  (c2.rank + self.cap.dir) % self.cap.mod == c1.rank))
@@ -196,7 +191,7 @@ class Alaska(RussianSolitaire):
 # ************************************************************************
 
 class Roslin_RowStack(Yukon_AC_RowStack):
-    def _isSequence(self, c1, c2):
+    def _isYukonSequence(self, c1, c2):
         return (c1.color != c2.color and
                 ((c1.rank + self.cap.dir) % self.cap.mod == c2.rank or
                  (c2.rank + self.cap.dir) % self.cap.mod == c1.rank))
@@ -294,7 +289,7 @@ class Abacus_Foundation(SS_FoundationStack):
 
 
 class Abacus_RowStack(Yukon_SS_RowStack):
-    def _isSequence(self, c1, c2):
+    def _isYukonSequence(self, c1, c2):
         dir, mod = -(c1.suit + 1), 13
         return c1.suit == c2.suit and (c1.rank + dir) % mod == c2.rank
 
@@ -592,7 +587,7 @@ class DoubleRussianSpider(RussianSpider, DoubleRussianSolitaire):
 # ************************************************************************
 
 class Brisbane_RowStack(Yukon_AC_RowStack):
-    def _isSequence(self, c1, c2):
+    def _isYukonSequence(self, c1, c2):
         return (c1.rank + self.cap.dir) % self.cap.mod == c2.rank
 
     def getHelp(self):
