@@ -21,31 +21,28 @@
 #
 # ---------------------------------------------------------------------------
 
-
-# imports
 import os
-from . import ttk
-from six.moves import UserList
 
-# PySol imports
-from pysollib.mygettext import _
-from pysollib.mfxutil import destruct, Struct, KwStruct
-from pysollib.mfxutil import format_time
 from pysollib.gamedb import GI
+from pysollib.mfxutil import KwStruct, Struct, destruct
+from pysollib.mfxutil import format_time
+from pysollib.mygettext import _
 from pysollib.resource import CSI
-
-# Toolkit imports
-from pysollib.ui.tktile.tkutil import unbind_destroy
 from pysollib.ui.tktile.selecttree import SelectDialogTreeData
-from .tkwidget import MfxDialog, MfxScrolledCanvas
-from .selecttree import SelectDialogTreeLeaf, SelectDialogTreeNode
-from .selecttree import SelectDialogTreeCanvas
+from pysollib.ui.tktile.tkutil import unbind_destroy
 
+from six.moves import UserList
+from six.moves import tkinter_ttk as ttk
+
+from .selecttree import SelectDialogTreeCanvas
+from .selecttree import SelectDialogTreeLeaf, SelectDialogTreeNode
+from .tkwidget import MfxDialog, MfxScrolledCanvas
 
 # ************************************************************************
 # * Nodes
 # ************************************************************************
 
+
 class SelectGameLeaf(SelectDialogTreeLeaf):
     pass
 
@@ -82,7 +79,8 @@ class SelectGameData(SelectDialogTreeData):
     def __init__(self, app):
         SelectDialogTreeData.__init__(self)
         self.all_games_gi = list(map(
-            app.gdb.get, app.gdb.getGamesIdSortedByName()))
+            app.gdb.get,
+            app.gdb.getGamesIdSortedByName()))
         self.no_games = [SelectGameLeaf(None, None, _("(no games)"), None), ]
         #
         s_by_type = s_oriental = s_special = s_original = s_contrib = \
@@ -146,7 +144,7 @@ class SelectGameData(SelectDialogTreeData):
             if name is None or not list(filter(
                     select_func, self.all_games_gi)):
                 continue
-            name = _("New games in v. ") + name
+            name = _("New games in v. %(version)s") % {'version': name}
             gg.append(SelectGameNode(None, name, select_func))
         if 1 and gg:
             s_by_pysol_version = SelectGameNode(None, _("by PySol version"),
@@ -232,8 +230,6 @@ class SelectGameData(SelectDialogTreeData):
                                    lambda gi: gi.si.redeals == 3),
                     SelectGameNode(None, _("Unlimited redeals"),
                                    lambda gi: gi.si.redeals == -1),
-                    # SelectGameNode(None, "Variable redeals",
-                    #                 lambda gi: gi.si.redeals == -2),
                     SelectGameNode(
                         None, _("Other number of redeals"),
                         lambda gi: gi.si.redeals not in (-1, 0, 1, 2, 3)),
@@ -330,6 +326,7 @@ class SelectGameDialog(MfxDialog):
             dir = os.path.join("html", "rules")
             from pysollib.help import help_html
             help_html(self.app, doc, dir, self.top)
+            self.top.grab_release()  # Don't want the help window appear frozen
             return
         MfxDialog.mDone(self, button)
 
@@ -487,7 +484,6 @@ class SelectGameDialogWithPreview(SelectGameDialog):
                 audio=self.app.audio,
                 canvas=canvas,
                 cardset=self.app.cardset.copy(),
-                comments=self.app.comments.new(),
                 gamerandom=self.app.gamerandom,
                 gdb=self.app.gdb,
                 gimages=self.app.gimages,
@@ -517,7 +513,7 @@ class SelectGameDialogWithPreview(SelectGameDialog):
         # self.top.wm_title("Select Game - " +
         #   self.app.getGameTitleName(gameid))
         title = self.app.getGameTitleName(gameid)
-        self.top.wm_title(_("Playable Preview - ") + title)
+        self.top.wm_title(_("Playable Preview - %(game)s") % {'game': title})
         #
         self.preview_game = gi.gameclass(gi)
         self.preview_game.createPreview(self.preview_app)
