@@ -24,13 +24,13 @@
 # imports
 import os
 import sys
-from six.moves import tkinter
-from . import ttk
 
-# PySol imports
 from pysollib.mygettext import _
 
-# Toolkit imports
+import six
+from six.moves import tkinter
+from six.moves import tkinter_ttk as ttk
+
 from .tkwidget import MfxTooltip
 
 if __name__ == '__main__':
@@ -39,9 +39,6 @@ if __name__ == '__main__':
     import gettext
     gettext.install('pysol', d, unicode=True)
 
-if sys.version_info > (3,):
-    unicode = str
-
 # ************************************************************************
 # *
 # ************************************************************************
@@ -99,7 +96,7 @@ class MfxStatusbar:
     def updateText(self, **kw):
         for k, v in kw.items():
             label = getattr(self, k + '_label')
-            text = unicode(v)
+            text = six.text_type(v)
             width = label['width']
             if width and len(text) > width:
                 label['width'] = len(text)
